ggmix_fitprint method for objects of class ggmix_fit
# S3 method for ggmix_fit
print(x, ..., digits = max(3, getOption("digits") - 3))# S3 method for ggmix_gic
print(x, ..., digits = max(3, getOption("digits") - 3))
an object of class objects of class ggmix_fit
other arguments passed to print
significant digits in printout. Default: max(3,
getOption("digits") - 3)
The call that produced the object x is printed, followed by a
three-column matrix with columns Df, %Dev, and and
Lambda. The Df columns correspond to the number of nonzero
coefficients including variance components. %dev is the percent
deviance explained (relative to the null deviance). Lambda is the
sequence of converged tuning parameters.